@@ -4,12 +4,21 @@ from pysnmp.carrier.asynsock.base import AbstractSocketTransport
 from pysnmp.carrier import error
 from pysnmp import debug
 
-sockErrors = {
+sockErrors = { # Ignore these socket errors
     errno.ESHUTDOWN: 1,
     errno.ENOTCONN: 1,
-    errno.ECONNRESET: 1
+    errno.ECONNRESET: 0,
+    errno.ECONNREFUSED: 0,
+    errno.EAGAIN: 0,
+    errno.EWOULDBLOCK: 0
     }
-    
+try:
+    # bad FD may happen upon FD closure on n-1 select() event
+    sockErrors[errno.EBADFD] = 1
+except AttributeError:
+    # Windows sockets do not have EBADFD
+    pass
+
 class DgramSocketTransport(AbstractSocketTransport):
     sockType = socket.SOCK_DGRAM
     retryCount = 3; retryInterval = 1
@@ -43,19 +52,20 @@ class DgramSocketTransport(AbstractSocketTransport):
     def writable(self): return self.__outQueue
     def handle_write(self):
         outgoingMessage, transportAddress = self.__outQueue.pop()
+        debug.logger & debug.flagIO and debug.logger('handle_write: transportAddress %s outgoingMessage %s' % (transportAddress, repr(outgoingMessage)))
         try:
             self.socket.sendto(outgoingMessage, transportAddress)
         except socket.error, why:
-            if why[0] != errno.EWOULDBLOCK:
+            if sockErrors.has_key(why[0]):
+                debug.logger & debug.flagIO and debug.logger('handle_write: ignoring socket error %s' % (why))
+            else:
                 raise socket.error, why
-        else:
-            debug.logger & debug.flagIO and debug.logger('handle_write: transportAddress %s outgoingMessage %s' % (transportAddress, repr(outgoingMessage)))
             
     def readable(self): return 1
     def handle_read(self):
         try:
             incomingMessage, transportAddress = self.socket.recvfrom(65535)
-            debug.logger & debug.flagIO and debug.logger('handle_read: transportAddress %s incomintMessage %s' % (transportAddress, repr(incomingMessage)))
+            debug.logger & debug.flagIO and debug.logger('handle_read: transportAddress %s incomingMessage %s' % (transportAddress, repr(incomingMessage)))
             if not incomingMessage:
                 self.handle_close()
                 return
@@ -64,7 +74,8 @@ class DgramSocketTransport(AbstractSocketTransport):
                 return
         except socket.error, why:
             if sockErrors.has_key(why[0]):
-                self.handle_close()
+                debug.logger & debug.flagIO and debug.logger('handle_read: known socket error %s' % (why))
+                sockErrors[why[0]] and self.handle_close()
                 return
             else:
                 raise socket.error, why
