@@ -13,6 +13,7 @@ from pysnmp.proto.secmod.rfc3414 import localkey
 from pysnmp.entity import engine
 from pysnmp.proto.secmod.rfc3414.auth import hmacmd5, hmacsha, noauth
 from pysnmp.proto.secmod.rfc3414.priv import des, nopriv
+from pysnmp.proto.secmod.rfc3826.priv import aes
 from pysnmp.smi.error import NotWritableError
 from pysnmp import error
 
@@ -28,6 +29,7 @@ usmNoAuthProtocol = noauth.NoAuth.serviceID
 
 # Privacy protocol
 usmDESPrivProtocol = des.Des.serviceID
+usmAesCfb128Protocol = aes.Aes.serviceID
 usmNoPrivProtocol = nopriv.NoPriv.serviceID
 
 def __cookV1SystemInfo(snmpEngine, securityName):
@@ -136,7 +138,8 @@ def addV3User(snmpEngine, securityName,
     else:
         raise error.PySnmpError('Unknown auth protocol %s' % (authProtocol,))
 
-    if privProtocol == usmDESPrivProtocol:
+    if privProtocol == usmDESPrivProtocol or \
+       privProtocol == usmAesCfb128Protocol:
         if authProtocol == usmHMACMD5AuthProtocol:
             hashedPrivPassphrase = localkey.hashPassphraseMD5(
                 privKey and privKey or ''
@@ -416,102 +419,102 @@ def delVacmView(snmpEngine, viewName, subTree):
 
 # VACM simplicity wrappers
 
-def __cookVacmUserInfo(snmpEngine, securityModel, securityName,
-                       securityLevel, mode):
-    groupName = '%s-view-%s-%d' % (securityName, mode, securityModel)
+def __cookVacmUserInfo(snmpEngine, securityModel, securityName, securityLevel):
+    groupName = 'v-%s-%d' % (hash(securityName), securityModel)
     SnmpSecurityLevel, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('SNMP-FRAMEWORK-MIB', 'SnmpSecurityLevel')
     securityLevel = SnmpSecurityLevel(securityLevel)
-    return groupName, securityLevel
+    return ( groupName, securityLevel,
+             'r' + groupName, 'w' + groupName, 'n' + groupName )
 
-def addRoUser(snmpEngine, securityModel, securityName, securityLevel, subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'ro'
+def addVacmUser(snmpEngine, securityModel, securityName, securityLevel,
+                readSubTree=(), writeSubTree=(), notifySubTree=()):
+    ( groupName, securityLevel,
+      readView, writeView, notifyView ) = __cookVacmUserInfo(
+        snmpEngine, securityModel, securityName, securityLevel,
         )
     addVacmGroup(
         snmpEngine, groupName, securityModel, securityName
         )
     addVacmAccess(
         snmpEngine, groupName, '', securityModel, securityLevel, 1,
-        groupName, '', ''
+        readView, writeView, notifyView
         )
-    addVacmView(
-        snmpEngine, groupName, 1, subTree, '',
+    if readSubTree:
+        addVacmView(
+            snmpEngine, readView, "included", readSubTree, '',
+            )
+    if writeSubTree:
+        addVacmView(
+            snmpEngine, writeView, "included", writeSubTree, '',
+            )
+    if notifySubTree:
+        addVacmView(
+            snmpEngine, notifyView, "included", notifySubTree, '',
+            )
+
+def delVacmUser(snmpEngine, securityModel, securityName, securityLevel,
+                readSubTree=(), writeSubTree=(), notifySubTree=()):
+    ( groupName, securityLevel,
+      readView, writeView, notifyView ) = __cookVacmUserInfo(
+        snmpEngine, securityModel, securityName, securityLevel,
+        )
+    delVacmGroup(
+        snmpEngine, securityModel, securityName
+        )
+    delVacmAccess(
+        snmpEngine, groupName, '', securityModel, securityLevel
+        )
+    if readSubTree:
+        delVacmView(
+            snmpEngine, readView, readSubTree
+            )
+    if writeSubTree:
+        delVacmView(
+            snmpEngine, writeView, writeSubTree
+            )
+    if notifySubTree:
+        delVacmView(
+            snmpEngine, notifyView, notifySubTree
+            )
+
+# Obsolete shortcuts for add/delVacmUser() wrappers
+
+def addRoUser(snmpEngine, securityModel, securityName, securityLevel, subTree):
+    addVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel, subTree
         )
 
 def delRoUser(snmpEngine, securityModel, securityName, securityLevel, subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'ro'
-        )
-    delVacmGroup(
-        snmpEngine, securityModel, securityName
-        )
-    delVacmAccess(
-        snmpEngine, groupName, '', securityModel, securityLevel
-        )
-    delVacmView(
-        snmpEngine, groupName, subTree
+    delVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel, subTree
         )
 
 def addRwUser(snmpEngine, securityModel, securityName, securityLevel, subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'rw'
-        )
-    addVacmGroup(
-        snmpEngine, groupName, securityModel, securityName
-        )
-    addVacmAccess(
-        snmpEngine, groupName, '', securityModel, securityLevel, 1,
-        groupName, groupName, ''
-        )
-    addVacmView(
-        snmpEngine, groupName, 1, subTree, ''
+    addVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel,
+        subTree, subTree
         )
 
 def delRwUser(snmpEngine, securityModel, securityName, securityLevel, subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'rw'
+    delVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel,
+        subTree, subTree
         )
-    delVacmGroup(
-        snmpEngine, securityModel, securityName
-        )
-    delVacmAccess(
-        snmpEngine, groupName, '', securityModel, securityLevel
-        )
-    delVacmView(
-        snmpEngine, groupName, subTree
-        )
-
-# Notification configuration
 
 def addTrapUser(snmpEngine,securityModel,securityName,securityLevel,subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'trap'
-        )
-    addVacmGroup(
-        snmpEngine, groupName, securityModel, securityName
-        )
-    addVacmAccess(
-        snmpEngine, groupName, '', securityModel, securityLevel, 1,
-        '', '', groupName,
-        )
-    addVacmView(
-        snmpEngine, groupName, 1, subTree, ''
+    addVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel,
+        (), (), subTree,
         )
 
 def delTrapUser(snmpEngine,securityModel,securityName,securityLevel,subTree):
-    groupName, securityLevel = __cookVacmUserInfo(
-        snmpEngine, securityModel, securityName, securityLevel, 'trap'
-        )
-    delVacmGroup(
-        snmpEngine, securityModel, securityName
-        )
-    delVacmAccess(
-        snmpEngine, groupName, '', securityModel, securityLevel
-        )
-    delVacmView(
-        snmpEngine, groupName, subTree
+    delVacmUser(
+        snmpEngine, securityModel, securityName, securityLevel,
+        (), (), subTree,
         )
 
+# Notification target setup
+
 def __cookNotificationTargetInfo(snmpEngine, notificationName, paramsName,
                                  filterSubtree=None):
     snmpNotifyEntry, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('SNMP-NOTIFICATION-MIB', 'snmpNotifyEntry')
@@ -524,7 +527,7 @@ def __cookNotificationTargetInfo(snmpEngine, notificationName, paramsName,
         paramsName
         )
 
-    profileName = '%s-filter' % notificationName
+    profileName = '%s-filter' % hash(notificationName)
     
     if filterSubtree:
         snmpNotifyFilterEntry, = snmpEngine.msgAndPduDsp.mibInstrumController.mibBuilder.importSymbols('SNMP-NOTIFICATION-MIB', 'snmpNotifyFilterEntry')
