@@ -71,7 +71,7 @@ class NotificationOriginator:
                 origContextName,
                 origPduVersion,
                 origPdu,
-                (self.processResponsePdu, origTimeout/1000 + time.time(),
+                (self.processResponsePdu, origTimeout/100 + time.time(),
                  (cbFun, cbCtx))
                 )
 
@@ -147,7 +147,10 @@ class NotificationOriginator:
             snmpTrapOid, = contextMibInstrumCtl.mibBuilder.importSymbols(
                 '__SNMPv2-MIB', 'snmpTrapOID'
                 )
-            varBinds.append((snmpTrapOid.name, snmpTrapOid.syntax))
+            if notificationName:
+                varBinds.append((snmpTrapOid.name, snmpTrapOid.syntax.clone(notificationName)))
+            else:
+                varBinds.append((snmpTrapOid.name, snmpTrapOid.syntax))
 
 # XXX it's still not clear how to instantiate OBJECTS clause
 #             # Get notification objects names
@@ -223,7 +226,7 @@ class NotificationOriginator:
                     contextName,
                     pduVersion,
                     pdu,
-                    (self.processResponsePdu, timeout/1000 + time.time(),
+                    (self.processResponsePdu, timeout/100 + time.time(),
                      (cbFun, cbCtx))
                     )
                 
