@@ -13,6 +13,7 @@ usmNoAuthProtocol = config.usmNoAuthProtocol
 
 # Privacy protocol
 usmDESPrivProtocol = config.usmDESPrivProtocol
+usmAesCfb128Protocol = config.usmAesCfb128Protocol
 usmNoPrivProtocol = config.usmNoPrivProtocol
 
 class CommunityData:
@@ -25,6 +26,12 @@ class CommunityData:
         if mpModel is not None:
             self.mpModel = mpModel
             self.securityModel = mpModel + 1
+            
+    def __repr__(self): return '%s("%s", <COMMUNITY>, %s)' % (
+        self.__class__.__name__,
+        self.securityName,
+        self.mpModel
+        )
 
 class UsmUserData:
     authKey = privKey = None
@@ -56,16 +63,29 @@ class UsmUserData:
                 self.privProtocol = usmDESPrivProtocol
             else:
                 self.privProtocol = privProtocol
+
+    def __repr__(self): return '%s("%s", <AUTHKEY>, <PRIVKEY>, %s, %s)' % (
+        self.__class__.__name__,
+        self.securityName,
+        self.authProtocol,
+        self.privProtocol
+        )
             
 class UdpTransportTarget:
     transportDomain = udp.domainName
-    def __init__(self, transportAddr, timeout=None, retries=None):
+    def __init__(self, transportAddr, timeout=1, retries=5):
         self.transportAddr = (
             socket.gethostbyname(transportAddr[0]), transportAddr[1]
             )
         self.timeout = timeout
         self.retries = retries
 
+    def __repr__(self): return '%s(("%s", %s), %s, %s)' % (
+        self.__class__.__name__,
+        self.transportAddr[0], self.transportAddr[1],
+        self.timeout, self.retries
+        )
+    
     def openClientMode(self):
         self.transport = udp.UdpSocketTransport().openClientMode()
         return self.transport
@@ -84,8 +104,10 @@ class AsynCommandGenerator:
         self.__knownTransports = {}
         self.__knownTransportAddrs = {}
 
+    def __del__(self): self.uncfgCmdGen()
+
     def cfgCmdGen(self, authData, transportTarget, tagList=''):
-        paramsName = '%s-params' % (authData.securityName,)
+        paramsName = 'p-%s' % hash(authData.securityName)
         if not self.__knownAuths.has_key(authData):
             if isinstance(authData, CommunityData):
                 config.addV1System(
@@ -121,15 +143,14 @@ class AsynCommandGenerator:
                 )
             self.__knownTransports[transportTarget.transportDomain] = 1
             
-        addrName = str(transportTarget.transportAddr)
+        addrName = 'a-%s' % hash((paramsName, transportTarget.transportAddr))
         if not self.__knownTransportAddrs.has_key(addrName):
             config.addTargetAddr(
                 self.snmpEngine, addrName,
                 transportTarget.transportDomain,
                 transportTarget.transportAddr,
                 paramsName,
-                transportTarget.timeout and transportTarget.timeout * 1000 \
-                or None,
+                transportTarget.timeout * 100,
                 transportTarget.retries,
                 tagList                
                 )
@@ -139,7 +160,7 @@ class AsynCommandGenerator:
 
     def uncfgCmdGen(self):
         for authData in self.__knownAuths.keys():
-            paramsName = '%s-params' % (authData.securityName,)
+            paramsName = 'p-%s' % hash(authData.securityName)
             if isinstance(authData, CommunityData):
                 config.delV1System(
                     self.snmpEngine,
@@ -200,6 +221,18 @@ class AsynCommandGenerator:
             name, oid = mibvar.mibNameToOid(
                 self.mibViewController, varName
                 )
+            if not type(varVal) == types.InstanceType:
+                ((symName, modName), suffix) = mibvar.oidToMibName(
+                    self.mibViewController, name + oid
+                    )
+                syntax = mibvar.cloneFromMibValue(
+                    self.mibViewController, modName, symName, varVal
+                    )
+                if syntax is None:
+                    raise error.PySnmpError(
+                        'Value type MIB lookup failed for %s' % repr(varName)
+                        )
+                varVal = syntax.clone(varVal)
             __varBinds.append((name + oid, varVal))
         return cmdgen.SetCommandGenerator().sendReq(
             self.snmpEngine, addrName, __varBinds, cbFun, cbCtx
