@@ -89,6 +89,8 @@ class SnmpV3MessageProcessingModel(AbstractMessageProcessingModel):
             (transportDomain, transportAddress)
             )
 
+        debug.logger & debug.flagMP and debug.logger('prepareOutgoingMessage: peer SNMP engine data %s for transport %s, address %s' % (peerSnmpEngineData, transportDomain, transportAddress))
+        
         # 7.1.4
         if contextEngineId is None:
             if peerSnmpEngineData is None:
@@ -167,7 +169,7 @@ class SnmpV3MessageProcessingModel(AbstractMessageProcessingModel):
             securityEngineID = snmpEngineID
         else:
             if peerSnmpEngineData is None:
-                # Force engineID discovery
+                # Force engineID discovery (rfc3414, 4)
                 securityEngineID = securityName = ''
                 securityLevel = 1
                 # Clear possible auth&priv flags
