@@ -1,8 +1,11 @@
+from pysnmp.proto import error
+
 class AbstractAuthenticationService:
     serviceID = None
     # 7.2.4.1
     def authenticateOutgoingMsg(self, authKey, wholeMsg):
-        pass
+        raise error.ProtocolError('no authentication')
+
     # 7.2.4.2
     def authenticateIncomingMsg(self, authKey, authParameters, wholeMsg):
-        pass
+        raise error.ProtocolError('no authentication')
